@@ -11,7 +11,6 @@ from rest_framework.views import APIView
 from .helpers import facebook_parse_signed_request
 from .models import FacebookAccessToken, FacebookUser
 from .serializers import (
-    AccountKitAuthTokenSerializer,
     FacebookAuthTokenSerializer,
     GoogleAuthTokenSerializer,
     AuthResultSerializer,
@@ -98,10 +97,6 @@ class FacebookDeleteView(APIView):
         return data
 
 
-class AccountKitRedirectView(OAuthRedirectViewBase):
-    serializer_class = AccountKitAuthTokenSerializer  # type: ignore
-
-
 class FacebookRedirectView(OAuthRedirectViewBase):
     serializer_class = FacebookAuthTokenSerializer  # type: ignore
 
